@@ -21,6 +21,7 @@ pub struct Config {
     delimiter: Delimiter,
     os: Os,
     host: Host,
+    kernel: Kernel,
 
     #[serde(flatten)]
     custom_modules: HashMap<String, Module>,
@@ -82,6 +83,7 @@ impl Config {
                 ),
                 "os" => vec.push(self.os.get_info().await),
                 "host" => vec.push(self.host.get_info().await),
+                "kernel" => vec.push(self.kernel.get_info().await),
                 v if !self.custom_modules.is_empty() && self.custom_modules.contains_key(v) => {
                     vec.push(self.custom_modules.get(v).unwrap().get_info().await)
                 }
@@ -362,12 +364,13 @@ impl Default for Config {
         Config {
             user: User::default(),
             offset: 4,
-            module_order: String::from("user delimiter os host"),
+            module_order: String::from("user delimiter os host kernel"),
             logo_cmd: String::from("auto"),
             format: Format::default(),
             delimiter: Delimiter::default(),
             os: Os::default(),
             host: Host::default(),
+            kernel: Kernel::default(),
             custom_modules: HashMap::new(),
         }
     }
